@@ -95,7 +95,7 @@ try:
 except:
 	has_numpy = False
 
-__version__ = '1.0.3'
+__version__ = '1.0.4'
 
 def NoneStr(obj): return 'NULL'
 
@@ -374,7 +374,7 @@ class R: # (object):
 			'localhost' : host=='localhost', 
 			'tail' : sys.platform=='win32' and '\r\n' or '\n'})
 
-		RCMD = shlex.split(RCMD) #re.split(r'\s', RCMD)
+		RCMD = [RCMD] #shlex.split(RCMD) - shlex do not work properly on Windows! #re.split(r'\s', RCMD)
 		if not self.localhost:
 			RCMD.insert(0, host)
 			if user:
